@@ -201,10 +201,10 @@ class Build(object):
             )
 
 # Infos given by the user.
-        self.path = path
-        self.pathNoExt = path[:-4]
+        self.path      = path
+        self.pathNoExt = osUse.fileName(path)
 
-        self.repeat = repeat
+        self.repeat  = repeat
         self.verbose = verbose
 
 # General infos about the LaTeX distribution and the OS.
