@@ -2,7 +2,7 @@
 
 """
 Name    : osUse
-Version : 2012.09
+Version : 2013.04
 Author  : Christophe BAL
 Mail    : projetmbc@gmail.com
 
@@ -52,9 +52,7 @@ def hasExtIn(
     """
     if '.' in path:
         for oneExtension in listOfExt:
-            L = len(oneExtension) + 1
-
-            if path[-L:] == '.' + oneExtension:
+            if path.endswith('.' + oneExtension):
                 return True
 
     return False
@@ -64,12 +62,14 @@ def hasExtIn(
 # -- INFOS ABOUT PATHS -- #
 # ----------------------- #
 
+SEP = os.sep
+
 def name(path):
     """
     This function extracts from one path the name of one file with its extension
     or simply the name of one directory.
     """
-    i = path.rfind(os.sep)
+    i = path.rfind(SEP)
 
     return path[i+1:]
 
@@ -78,9 +78,7 @@ def fileName(path):
     This function extracts the name without its extension of one file given by
     its path.
     """
-    i = path.rfind(os.sep)
-
-    return os.path.splitext(path[i+1:])[0]
+    return os.path.splitext(name(path))[0]
 
 def ext(path):
     """
@@ -88,6 +86,19 @@ def ext(path):
     """
     return os.path.splitext(path)[1][1:]
 
+def pathNoExt(path):
+    """
+    This function removes the extension of one file in its path.
+    """
+    i = len(ext(path))
+
+    if i != 0:
+        i += 1
+
+        return path[:-i]
+
+    return path
+
 def parentDir(path):
     """
     This function returns the path of the directory that contains the file or
@@ -129,8 +140,8 @@ def relativePath(
 # is not one sub path of
 #     "python/Mistool/source".
 
-    if main[-1] != os.sep:
-        main += os.sep
+    if main[-1] != SEP:
+        main += SEP
 
 # Is the sub path contained in the main one ?
     if not sub.startswith(main):
@@ -177,7 +188,7 @@ def relativeDepth(
     return relativePath(
         main        = main,
         sub         = sub
-    ).count(os.sep) - 1
+    ).count(SEP) - 1
 
 def commonPath(
     listPath
@@ -194,8 +205,8 @@ def commonPath(
     if len(listPath) == 2:
         answer = []
 
-        path1 = listPath[0].split(os.sep)
-        path2 = listPath[1].split(os.sep)
+        path1 = listPath[0].split(SEP)
+        path2 = listPath[1].split(SEP)
 
         for i in range(min(len(path1), len(path2))):
             if path1[i] == path2[i]:
@@ -203,7 +214,7 @@ def commonPath(
             else:
                 break
 
-        return os.sep.join(answer)
+        return SEP.join(answer)
 
     else:
         return commonPath([
@@ -420,12 +431,25 @@ def __isSubDepthGood(
             relativeDepth(main = main, sub = sub) <= depth - 1
         )
 
+def __toKeepToDiscard(extVar):
+    extToKeep = extVar.get('keep', [])
+
+    if type(extToKeep) == str:
+        extToKeep = [extToKeep]
+
+    extToDiscard = extVar.get('discard', [])
+
+    if type(extToDiscard) == str:
+        extToDiscard = [extToDiscard]
+
+    return extToKeep, extToDiscard
+
 def nextFile(
     main,
-    ext      = {},
-    depth    = 0,
-    sub      = {},
-    keepDir  = None
+    ext     = {},
+    depth   = 0,
+    sub     = {},
+    keepDir = None
 ):
     """
     This function is one iterator that sends infos about files that respects
@@ -448,6 +472,8 @@ def nextFile(
         If ``ext`` is an empty dictionary, or if the two lists are empty ones
         then the function will send every kind of files.
 
+        One last thing, if you only need to consider one extension, you can just give it without using one single value list.
+
         3) ``depth`` is the maximal depth for the research. The very special
         value ``(-1)`` indicates that there is no maximum. The default value is
         ``0`` which asks to only look for in the direct content of the main
@@ -476,12 +502,8 @@ def nextFile(
 
         python::
             {
-                'change_log': {
-                    'keep'   : ['txt']
-                },
-                'debug': {
-                    'depth': 0
-                }
+                'change_log': {'keep': "txt"},
+                'debug'     : {'depth': 0}
             }
 
         In the preceding dictionary, the keys are the relative path of the sub
@@ -503,7 +525,7 @@ def nextFile(
             {
                 'change_log': {
                     'inherit': True ,
-                    'keep'   : ['txt']
+                    'keep'   : "txt"
                 }
             }
 
@@ -554,8 +576,8 @@ def nextFile(
     for oneRelativePath in sub:
         realPath = oneRelativePath
 
-        if not realPath.startswith('/'):
-            realPath = '/' + realPath
+        if not realPath.startswith(SEP):
+            realPath = SEP + realPath
 
         realPath = main + realPath
 
@@ -568,18 +590,18 @@ def nextFile(
         listOfsubPath.append(realPath)
         subRelativePaths[realPath] = oneRelativePath
 
-    extToKeep    = ext.get('keep', [])
-    extToDiscard = ext.get('discard', [])
+    extToKeep, extToDiscard = __toKeepToDiscard(ext)
 
     for root, dirs, files in os.walk(main):
 ### CASE OF ONE SUB DIRECTORY WITH SPECIAL CRITERIONS ###
         if root in listOfsubPath:
             subResearch = sub[subRelativePaths[root]]
 
-            inherit         = subResearch.get('inherit', False)
-            subExtToKeep    = subResearch.get('keep', [])
-            subExtToDiscard = subResearch.get('discard', [])
-            subDepth        = subResearch.get('depth', 0)
+            inherit = subResearch.get('inherit', False)
+
+            subExtToKeep, subExtToDiscard = __toKeepToDiscard(subResearch)
+
+            subDepth = subResearch.get('depth', 0)
 
 # Inherit or not inherit ? That is the question...
             if inherit:
@@ -589,13 +611,13 @@ def nextFile(
 
 # Let's look for the files in the sub directory...
             for oneFileInsub in nextFile(
-                main  = root,
+                main = root,
                 ext  = {
                     'keep'   : subExtToKeep,
                     'discard': subExtToDiscard
                 },
-                depth = subDepth,
-                keepDir  = keepDir
+                depth   = subDepth,
+                keepDir = keepDir
             ):
                 yield oneFileInsub
 
@@ -609,7 +631,7 @@ def nextFile(
             noGoodFileFound = True
 
             for oneFile in files:
-                path = root + os.sep + oneFile
+                path = root + SEP + oneFile
 
                 if not hasExtIn(path, extToDiscard):
                     if extToKeep:
@@ -640,7 +662,7 @@ def nextFile(
 
 # Directory without some good files
             if indicateAllFiles and not noBadFileFound:
-                yield root + os.sep + "..."
+                yield root + SEP + "..."
 
 def listFile(*args, **kwargs):
     """
@@ -698,16 +720,18 @@ class DirView(object):
     def __init__(
         self,
         main,
-        ext      = {},
-        depth    = 0,
-        sub      = {},
-        keepDir  = "minimal",
-        output   = "all",
-        seeMain  = True
+        ext     = {},
+        depth   = 0,
+        sub     = {},
+        keepDir = "minimal",
+        output  = "all",
+        seeMain = True
     ):
 # Directories to keep ?
         if keepDir == None:
-            raise MistoolOsUseError("Illegal value of the variable ''keepDir''.")
+            raise MistoolOsUseError(
+                "Illegal value of the variable << keepDir >>."
+            )
 
         self.main    = main
         self.ext     = ext
@@ -717,12 +741,11 @@ class DirView(object):
         self.output  = output
         self.seeMain = seeMain
 
-        self.listView = []
-        self.format   = {}
+        self.build()
 
     def build(self):
         """
-        This function returns one list of dictionary of the following kind.
+        This function builds one list of dictionary of the following kind.
 
         python::
             {
@@ -731,6 +754,7 @@ class DirView(object):
                 'path' : the path of one directory or file found
             }
         """
+        self.listView = []
         self.format   = {}
 
         for onePath in nextFile(
@@ -757,6 +781,30 @@ class DirView(object):
 # The depth
                 depth = relativeDepth(self.main, onePath)
 
+# << WARNING ! >> We must take care of directories without any file which
+# have the same depth of previous files.
+                if kind == "directory" and self.listView:
+                    if depth >= self.listView[-1]['depth']:
+                        lastParentDir = commonPath([
+                            self.listView[-1]['path'],
+                            onePath
+                        ])
+
+                        i = len(lastParentDir) + 1
+
+                        listSubDirName = onePath[i:].split(SEP)
+                        lastDepth      = depth - len(listSubDirName)
+
+                        for oneSubDirName in listSubDirName[:-1]:
+                            lastParentDir += SEP + oneSubDirName
+                            lastDepth     += 1
+
+                            self.listView.append({
+                                'kind' : "directory",
+                                'depth': lastDepth,
+                                'path' : lastParentDir
+                            })
+
 # Let's store the infos found.
                 self.listView.append({
                     'kind' : kind,
@@ -765,7 +813,7 @@ class DirView(object):
                 })
 
     def __otherFiles(self, onePath):
-        return bool(onePath[-3:] == "...")
+        return onePath.endswith("...")
 
     def pathToDisplay(
         self,
@@ -777,13 +825,13 @@ class DirView(object):
 
         elif self.output == "relative":
             if self.main == onePath:
-                return onePath[len(parentDir(onePath))+1:]
+                return onePath[len(parentDir(onePath)) + 1:]
             else:
                 return relativePath(self.main, onePath)
 
         elif self.output == "short":
             if kind == "file":
-                return onePath[onePath.rfind(os.sep)+1:]
+                return onePath[onePath.rfind(SEP)+1:]
 
             else:
                 return onePath[len(parentDir(onePath))+1:]
