@@ -117,7 +117,7 @@ def beforeAfter(
 
         if s == -1:
             raise MistoolStringUseError(
-                'The following text has not been found.\n\t>>> {0}'.format(start)
+                'The starting text << {0} >> has not been found.'.format(start)
             )
 
         s += len(start)
@@ -128,10 +128,12 @@ def beforeAfter(
     else:
         e = text.find(end, s)
 
-        if s == -1:
+        if e == -1:
+            message = 'The ending text  << {0} >> has not been found after ' \
+                    + 'the first text << {1} >>.'
+
             raise MistoolStringUseError(
-                'The secund following text has not been found after the first '
-                'one.\n\t>>> {0}\n\t>>> {1}'.format(start, end)
+                message.format(start, end)
             )
 
         if start == "":
@@ -368,7 +370,7 @@ def __drawHorizontalRule(
 
 def frame(
     text,
-    kind,
+    format,
     center = True
 ):
     """
@@ -397,7 +399,7 @@ def frame(
         print(
             Mistool.stringUse.frame(
                 text   = textToDecorate,
-                kind   = Mistool.stringUse.PYTHON_FRAME,
+                format = Mistool.stringUse.PYTHON_FRAME,
                 center = False
             )
         )
@@ -436,7 +438,7 @@ def frame(
             }
         }
 
-    This will give the following kind of frame.
+    This will give the following format of frame.
 
     code_c::
         /***************
@@ -467,7 +469,7 @@ def frame(
             }
         }
 
-    This will give the following kind of frame.
+    This will give the following format of frame.
 
     python::
         # ------------- #
@@ -511,24 +513,24 @@ def frame(
     """
 # Default values must be choosen if nothing is given.
     for key in ['rule', 'corner']:
-        if key not in kind:
-            kind[key] = {}
+        if key not in format:
+            format[key] = {}
 
     for styleKey in ['up', 'down', 'left', 'right']:
-        if styleKey not in kind['rule']:
-            kind['rule'][styleKey] = ""
+        if styleKey not in format['rule']:
+            format['rule'][styleKey] = ""
 
     for styleKey in ['leftup', 'leftdown', 'rightup', 'rightdown']:
-        if styleKey not in kind['corner']:
-            kind['corner'][styleKey] = ""
+        if styleKey not in format['corner']:
+            format['corner'][styleKey] = ""
 
 # Horizontal rules can only use one single character.
     for onePosition in ['up', 'down']:
-        if len(kind['rule'][onePosition]) > 1:
+        if len(format['rule'][onePosition]) > 1:
             raise MistoolStringUseError(
                 "You can only use nothing or one single charcater for rules." \
                 "\nSee ''{0}'' for the {1} rule.".format(
-                    kind['rule'][onePosition],
+                    format['rule'][onePosition],
                     onePosition
                 )
             )
@@ -539,20 +541,20 @@ def frame(
 
 # Space to add before vertical rules.
     nbSpaceToAdd = max(
-        len(kind['corner']['leftup']),
-        len(kind['corner']['leftdown'])
+        len(format['corner']['leftup']),
+        len(format['corner']['leftdown'])
     )
 
     spaceToAdd = ' '*nbSpaceToAdd
 
 # Text decoration for vertical rules
-    if kind['rule']['left']:
-        leftRuleText = kind['rule']['left'] + ' '
+    if format['rule']['left']:
+        leftRuleText = format['rule']['left'] + ' '
     else:
         leftRuleText = ''
 
-    if kind['rule']['right']:
-        rightRuleText = ' ' + kind['rule']['right']
+    if format['rule']['right']:
+        rightRuleText = ' ' + format['rule']['right']
     else:
         rightRuleText = ''
 
@@ -561,9 +563,9 @@ def frame(
 
 # First line of the frame
     answer = __drawHorizontalRule(
-        charRule     = kind['rule']['up'],
-        leftCorner   = kind['corner']['leftup'],
-        rightCorner  = kind['corner']['rightup'],
+        charRule     = format['rule']['up'],
+        leftCorner   = format['corner']['leftup'],
+        rightCorner  = format['corner']['rightup'],
         ruleLenght   = ruleLenght,
         nbSpaceToAdd = nbSpaceToAdd
     )
@@ -592,19 +594,19 @@ def frame(
             spaceToAdd
             +
             '{0}{1}{2}{3}{4}'.format(
-                    leftRuleText,
-                    spaceBefore,
-                    oneLine,
-                    spaceAfter,
-                    rightRuleText
-                )
+                leftRuleText,
+                spaceBefore,
+                oneLine,
+                spaceAfter,
+                rightRuleText
+            )
         )
 
 # Last line of the frame
     answer += __drawHorizontalRule(
-        charRule     = kind['rule']['down'],
-        leftCorner   = kind['corner']['leftdown'],
-        rightCorner  = kind['corner']['rightdown'],
+        charRule     = format['rule']['down'],
+        leftCorner   = format['corner']['leftdown'],
+        rightCorner  = format['corner']['rightdown'],
         ruleLenght   = ruleLenght,
         nbSpaceToAdd = nbSpaceToAdd
     )
@@ -612,11 +614,11 @@ def frame(
     answer = '\n'.join(answer)
 
 # Does we have an extra frame ?
-    if 'extra' in kind:
+    if 'extra' in format:
         try:
             answer = frame(
                 text   = answer,
-                kind   = kind['extra'],
+                format = format['extra'],
                 center = center
             )
 
@@ -743,7 +745,7 @@ def __indentation(text):
 
 def cut(
     text,
-    width  = 80
+    width = 80
 ):
     """
     This function tries to cut lines of one text so as to have less than `81`
